pyjabber.stream.server package
==============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyjabber.stream.server.incoming
   pyjabber.stream.server.outcoming

Module contents
---------------

.. automodule:: pyjabber.stream.server
   :members:
   :undoc-members:
   :show-inheritance:
